---
hide:
    - navigation
    - toc
---
# Frequently Asked Questions

## How do you determine if a model is "Commercial" or not?

We generally determine this based on whether a model's license allows commercial use of
the model. However if we are aware that a model is trained on data, that does not allow
for commercial use, we will specify it as non-commercial model, despite the stated
license. This includes models trained on data generated by proprietary models, whose
terms of use states that their outputs cannot be used to train competing models (this
includes OpenAI, Gemini, Claude, Grok, and others). If you find an issue with any of
models feel free to open an [issue](https://github.com/EuroEval/EuroEval/issues).

## Not finding the answer that you are looking for?

If don't find the answer that you are looking for feel free to ask your question in the
[forum](https://github.com/EuroEval/EuroEval/discussions).
